;; Emacs mode for GRL
;; Maintainer:	Syntax Editor Configuration Tool <cadp@inria.fr>
;; Version:	1.8:GRL+1.8:SECT

;;; ----------------------------------------------------------------------------
;;;                                DEFINITIONS
;;; ----------------------------------------------------------------------------

(defvar grl-mode-syntax-table nil
   "Syntax table used while in GRL mode")
(if grl-mode-syntax-table
      ()
   (setq grl-mode-syntax-table (make-syntax-table))
   (modify-syntax-entry ?+ "."   grl-mode-syntax-table)
   (modify-syntax-entry ?= "."   grl-mode-syntax-table)
   (modify-syntax-entry ?% "."   grl-mode-syntax-table)
   (modify-syntax-entry ?< "."   grl-mode-syntax-table)
   (modify-syntax-entry ?> "."   grl-mode-syntax-table)
   (modify-syntax-entry ?& "."   grl-mode-syntax-table)
   (modify-syntax-entry ?| "."   grl-mode-syntax-table)
   (modify-syntax-entry ?_ "w"   grl-mode-syntax-table)
   (modify-syntax-entry ?( "() 1"   grl-mode-syntax-table)
   (modify-syntax-entry ?* ". 23"   grl-mode-syntax-table)
   (modify-syntax-entry ?) ")( 4"   grl-mode-syntax-table)
   (modify-syntax-entry ?- ". 12b"   grl-mode-syntax-table)
   (modify-syntax-entry ?! "w"   grl-mode-syntax-table)
   (modify-syntax-entry ?\n "> b"   grl-mode-syntax-table)
   (modify-syntax-entry ?\' "\"'"   grl-mode-syntax-table)
)

;;; ----------------------------------------------------------------------------
;;;                                HIGHLIGHTING
;;; ----------------------------------------------------------------------------

(defvar grl-font-lock-keywords
   (list
      ;; line comments
      (cons "--.*$" 'font-lock-comment-face)
      ;; GRL pragmas
      (cons (regexp-opt '("!c" "!lnt") 'words)
             'font-lock-builtin-face)
      ;; GRL keywords
      (cons (regexp-opt '("alias" "any" "as" "array" "block" "by"
                          "case" "const" "else" "elsif" "enable" "end"
                          "environment" "enum" "for" "from" "if" "in"
                          "is" "list" "loop" "medium" "module" "null"
                          "of" "out" "range" "receive" "record" "select"
                          "send" "static" "system" "then" "to" "type"
                          "var" "when" "where" "while") 'words)
             'font-lock-keyword-face)
      ;; GRL types
      (cons (regexp-opt '("bool" "char" "nat" "nat16" "nat32" "int"
                          "int16" "int32" "string") 'words)
             'font-lock-type-face)
      ;; GRL constants
      (cons (regexp-opt '("false" "true") 'words)
             'font-lock-constant-face)
      ;; GRL functions
      (cons (regexp-opt '("abs" "and" "equ" "implies" "not" "or"
                          "xor") 'words)
             'font-lock-function-name-face)
      ;; key symbols
      (cons (regexp-opt '("+" "-" "/" "^" "%" "<"
                          ">" "|" "*" "?" "[]" "->"
                          "==" "!=" "<=" ">=") t)
             'font-lock-keyword-face)
   )
   "Keywords used in GRL mode")

;;; ----------------------------------------------------------------------------
;;;                                MODE
;;; ----------------------------------------------------------------------------

(setq aux-file (expand-file-name (concat (getenv "CADP") "/ext/emacs/grl-aux.el")))
(if (file-exists-p aux-file) (load aux-file))

(defun grl-mode ()
   "Running GRL mode"
   (interactive)
   (kill-all-local-variables)
   (setq major-mode 'grl-mode)
   (setq mode-name "GRL")
   (set-syntax-table grl-mode-syntax-table)
   (set (make-local-variable 'comment-start) "(*")
   (set (make-local-variable 'comment-end) "*)")
   (set (make-local-variable 'font-lock-defaults)
        '(grl-font-lock-keywords nil nil))
   (if (file-exists-p aux-file) (grl-entry-point))
   (run-hooks 'grl-mode-hook)
)

(provide 'grl-mode)

