" Vim syntax file
" Language:	GRL
" Maintainer:	Syntax Editor Configuration Tool <cadp@inria.fr>
" Last Change:	1.8:GRL+1.13:SECT

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

syntax case match
syntax sync lines=250

" Strings
syntax region grlSingleQuotedString start=+'+ end=+'+
syntax region grlDoubleQuotedString start=+"+ end=+"+

" Keywords
syntax keyword grlKeyword alias any as array block by
syntax keyword grlKeyword case const else elsif enable end
syntax keyword grlKeyword environment enum for from if in
syntax keyword grlKeyword is list loop medium module null
syntax keyword grlKeyword of out range receive record select
syntax keyword grlKeyword send static system then to type
syntax keyword grlKeyword var when where while

" Pragmas
syntax match grlPragma +!c+
syntax match grlPragma +!lnt+

" Basic Types
syntax keyword grlType bool char nat nat16 nat32 int
syntax keyword grlType int16 int32 string

" Constants
syntax keyword grlConstant false true

" Functions
syntax keyword grlFunction abs and equ implies not or
syntax keyword grlFunction xor

" Operators
syntax match grlOperator "+"
syntax match grlOperator "-"
syntax match grlOperator "/"
syntax match grlOperator "\^"
syntax match grlOperator "%"
syntax match grlOperator "<"
syntax match grlOperator ">"
syntax match grlOperator "|"
syntax match grlOperator "\*"
syntax match grlOperator "?"
syntax match grlOperator "\[\]"
syntax match grlOperator "->"
syntax match grlOperator "=="
syntax match grlOperator "!="
syntax match grlOperator "<="
syntax match grlOperator ">="

" Comments
syntax match grlComment +--.*+
syntax region grlComment start=+(\*+ end=+\*)+

" Highlighting
" For Vim version 5.7 and earlier: only when not done already
" For Vim version 5.8 and later: only when an item has no highlighting
if version >= 508 || !exists("did_lnt_syntax_inits")
  if version < 508
    let did_lnt_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif
  HiLink grlComment Comment
  HiLink grlSingleQuotedString Character
  HiLink grlDoubleQuotedString String
  HiLink grlBackQuotedString String
  HiLink grlKeyword Keyword
  HiLink grlPragma PreProc
  HiLink grlType Type
  HiLink grlConstant Boolean
  HiLink grlFunction Tag
  HiLink grlOperator Operator
  delcommand HiLink
endif

let b:current_syntax = "grl"

