.\" @(#)grl.open.l - CONVECS teams - 16/02/03
.TH GRL.OPEN LOCAL "16/02/03" "(C) INRIA" "CADP MANUAL PAGES"
.fp 4 CB
.lg 0

.SH NAME
grl.open \- OPEN/CAESAR connection for the GRL language

.SH SYNOPSIS
.B grl.open
[\fB\-print\fP \fIpp_file\fP[\fB.grl\fP]]
[\fB\-silent\fP | \fB\-verbose\fP]
[\fB\-version\fP]
[\fB\-about\fP]
[\fB\-ignore\fP]
[\fB\-warnings\fP]
[\fB\-merge\fP]
[\fB\-sync\fP]
[\fB\-warning\fP]
[\fB\-showall\fP]
[\fB\-force\fP]
[\fB\-relabel\fP]
[\fB\-root\fP \fIsystem\fP]
[\fB\-labels\fP]
.RI [ lnt_options ]
\fIfilename\fP[\fB.grl\fP]
.RI [ cc_options ]
\fIuser\fP[\fB.a\fP|\fB.c\fP|\fB.o\fP]
.RI [ user_options ]

.SH DESCRIPTION
Taking as input
.IB filename .grl
(which contains the principal program of a GRL specification) and an 
OPEN/CAESAR program \fIuser\fP[\fB.a\fP|\fB.c\fP|\fB.o\fP],
\fBgrl.open\fP operates as follows:
.IP -
First, it translates the GRL specification
.IB filename .grl
(including all transitively imported programs) into a LNT specification using 
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more  information.
.IP -
Then, it calls ``\fBlnt.open\fP
.RI [ lnt_options ]
.IB filename .lnt
.RI [ cc_options ]
\fIuser\fP[\fB.a\fP|\fB.c\fP|\fB.o\fP]
[\fIuser_options\fP]'', passing to \fBlnt.open\fP (and, 
transitively, \fPcaesar.open\fP, \fPcaesar.adt\fP and \fPcaesar\fP) appropriate 
options that depend on the options passed to \fBgrl.open\fP (see below). See
.BR lnt.open (LOCAL),
.BR caesar.open (LOCAL),
.BR caesar.adt (LOCAL),
and
.BR caesar (LOCAL)
for more information.
.br
\ 
.br
However, if \fIuser\fP is the "-" string (instead of the name of an 
OPEN/CAESAR application program), \fBgrl.open\fP will execute only the first 
step (translation into a LNT specification) and then stop without invoking 
\fBlnt.open\fP. In such case, the files generated during the first step are not 
removed.

.SH OPTIONS

.TP
.B \-print pp_file[.grl] \ \ \ 
Perform syntax and semantic analysis of \fIfilename\fP\fB.grl\fP, prints an 
indented form of the file in \fIpp_file\fP\fB.grl\fP and stops execution.
.TP
.B \-silent \ \ \ 
Execute silently, reporting only errors.
This is the opposite of \fB\-verbose\fP.
The default option is \fB\-verbose\fP.
This option is passed to
.BR grl2lnt (LOCAL),
and
.BR lnt.open (LOCAL).
See
.BR grl2lnt (LOCAL),
.BR lnt.open (LOCAL)
for more information.
.TP
.B \-verbose \ \ \ 
Report activities and progress, including errors, to the user's screen. 
This is the opposite of \fB\-silent\fP.
The default option is \fB\-verbose\fP.
This option is passed to
.BR grl2lnt (LOCAL),
and
.BR lnt.open (LOCAL).
See
.BR grl2lnt (LOCAL),
.BR lnt.open (LOCAL)
for more information.
.TP
.B \-version \ \ \ 
Display the version number of 
.BR grl2lnt (LOCAL)
and stop.
.TP
.B \-about \ \ \ 
Display information about
.BR grl.open (LOCAL)
and stop.
.TP
.B \-ignore \ \ \ 
Do not stop execution after an error is issued, force the generation of an LNT 
file (possibly with errors).
This option is passed to
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more information.
.TP
.B \-warnings \ \ \ 
Stop execution when a warning is issued in GRL specification and exit with 
status 1.
This option is passed to
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more information.
.TP
.B \-merge \ \ \ 
Use merge mode. It simulates the merge of transitions with adding a special 
merged transition and hiding everything else.
This option is passed to
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more information.
.TP
.B \-sync \ \ \ 
Use synchronous mode. It enables the generation of merged transitions.
The option should be used only on synchronous programs.
This option is passed to
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more information.
.TP
.B \-warning \ \ \ 
No warning is issued in the GRL specification.
This option is passed to
.BR grl2lnt (LOCAL),
and
.BR lnt.open (LOCAL).
See
.BR grl2lnt (LOCAL),
.BR lnt.open (LOCAL)
for more information.
.TP
.B \-showall \ \ \ 
Show all transitions.
This option is passed to
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more information.
.TP
.B \-force \ \ \ 
Overwrite output files, even if they were edited by the user or do not need to 
be updated.
This option is passed to
.BR grl2lnt (LOCAL),
and
.BR lnt.open (LOCAL).
See
.BR grl2lnt (LOCAL),
.BR lnt.open (LOCAL)
for more information.
.TP
.B \-relabel \ \ \ 
Generate a rename file to match formal definition of LTS labels (required by 
other tools).
This option is passed to
.BR grl2lnt (LOCAL).
See
.BR grl2lnt (LOCAL)
for more information.
.TP
.B \-root instantiation \ \ \ 
where \fIinstantiation\fP can take two different forms: \fBsystem\fP, or a 
character string of the form "\fIsystem (X1, ..., Xn)\fP" 
where \fIX1, ..., Xn\fP are values of the constant parameters of the system. It 
is highly recommended to type given parameters using syntax \fIof type\fP.
.br
If the option is specified, only the system \fBsystem\fP will be treated.
\fBgrl2lnt\fP will generate a Main process calling the process of the root 
system in the LNT specification.
By default, if the \fB\-root\fP option is absent, it is assumed that there is 
only one system in the program or that there exists a system called \fBMain\fP.
This option is passed to
.BR grl2lnt (LOCAL),
and
.BR lnt.open (LOCAL).
See
.BR grl2lnt (LOCAL),
.BR lnt.open (LOCAL)
for more information.
.TP
.B \-labels \ \ \ 
Display on user's screen the list of labels expected to be printed in the LNT 
specification and for example on the generated LTS.

.TP
.I lnt_options
if any, are passed to
.BR lnt.open (LOCAL).
.TP
.I cc_options
if any, are passed to the C compiler.
.TP
.I user_options
if any, are passed to \fIuser\fP.

.SH OPERANDS

.PD 0
.TP 16
.IB filename .grl
GRL specification (input)
.TP
.BI pp_file .grl
GRL code (optional output)
.TP
.BI filename .o
object code (output)
.TP
.BI filename .err
detailed error messages (output)
.TP
.BI user .a
exploration module (archive, input)
.TP
.BI user .c
exploration module (source, input)
.TP
.BI user .o
exploration module (object code, input)
.TP
.BI user
executable program (output)

.SH FILES

.PD 0
.TP 18
.B $CADP_TMP/lnt.*
temporary files
.TP
.B $GRL_LOCATION/lnt/GRL_V1.lnt
GRL predefined library (LNT code)
.TP
.B $GRL_LOCATION/incl/GRL_V1.h 
GRL predefined library (C code)

.SH EXIT STATUS

If the translation was successful the exit status is 0. If any error occurred 
during translation, the exit status is 1 and error messages are issued.

.SH AUTHOR
.P
Eric Leo.

.SH SEE ALSO
.P
.BR grl (LOCAL),
.BR grl2lnt (LOCAL),
.BR lnt.open (LOCAL),
.BR lnt2lotos (LOCAL),
.BR caesar.adt (LOCAL),
.BR caesar (LOCAL),

.P
Additional information is available from the CADP Web page located at
http://cadp.inria.fr
.P
Directives for installation are given in files \fB$GRL_LOCATION/INSTALLATION\fP.
.P
Recent changes and improvements to this software are reported
and commented in file \fB$GRL_LOCATION/VERSION\fP.

.SH BUGS

.P
Please report any bug to cadp@inria.fr
