.\" @(#)grl2lnt.l - CONVECS team - 16/02/03
.TH GRL2LNT LOCAL "16/02/03" "(C) INRIA" "CADP MANUAL PAGES"
.fp 4 CB
.lg 0

.SH NAME
grl2lnt \- GRL to LNT translator

.SH SYNOPSIS
.B grl2lnt
[\fB\-print\fP \fIpp_file\fP[\fB.grl\fP]]
[\fB\-silent\fP | \fB\-verbose\fP]
[\fB\-version\fP]
[\fB\-about\fP]
[\fB\-ignore\fP]
[\fB\-warnings\fP]
[\fB\-merge\fP]
[\fB\-sync\fP]
[\fB\-warning\fP]
[\fB\-showall\fP]
[\fB\-onlyroot\fP]
[\fB\-force\fP]
[\fB\-relabel\fP]
[\fB\-root\fP \fIsystem\fP]
\fIfilename\fP[\fB.grl\fP]

.SH DESCRIPTION 
GRL (GALS Representation Language) is an imperatively styled specification 
language for GALS systems. The \fBgrl2lnt\fP program translates a GRL 
specification to a LNT specification.
.PP
The input to \fBgrl2lnt\fP is a GRL file, which must have the 
extension \fB.grl\fP. If the user does not specify the extension \fB.grl\fP on 
the command line, it will be appended automatically and \fBgrl2lnt\fP will 
read \fIfilename\fP\fB.grl\fP as input.
.PP
The principal output of \fBgrl2lnt\fP is a LNT specification 
named \fIfilename\fP\fB.lnt\fP. An auxiliary file can also be generated if 
external C code is required, namely \fIfilename\fP\fB.fnt\fP, which contains 
C code for interfacing external data types and functions.
.PP
To avoid clashes between generated files and user\-written 
files, \fBgrl2lnt\fP writes a special tag at the beginning of each generated 
file. This tag is a comment containing the name and the version 
of \fBgrl2lnt\fP that generated the file.
\fBgrl2lnt\fP uses this tag to prevent \fBgrl2lnt\fP from overwriting a file 
that was not generated by itself: if the output file already exists but has no 
special tag or has an invalid tag indicating that the file was not generated 
by the right tool, \fBgrl2lnt\fP issues an error message and stops.

.SH OPTIONS

.TP
.B \-print pp_file[.grl] \ \ \ 
Perform syntax and semantic analysis of \fIfilename\fP\fB.grl\fP, prints an 
indented form of the file in \fIpp_file\fP\fB.grl\fP and stops execution.
.TP
.B \-silent \ \ \ 
Execute silently, reporting only errors.
This is the opposite of \fB\-verbose\fP.
The default option is \fB\-verbose\fP.
.TP
.B \-verbose \ \ \ 
Report activities and progress, including errors, to the user's screen. 
This is the opposite of \fB\-silent\fP.
The default option is \fB\-verbose\fP.
.TP
.B \-version \ \ \ 
Display the tool version and exit.
.TP
.B \-about \ \ \ 
Display information about the tool.
.TP
.B \-ignore \ \ \ 
Do not stop execution after an error is issued, force the generation of an LNT 
file (possibly with errors).
.TP
.B \-warnings \ \ \ 
Stop execution when a warning is issued and exit with status 1.
.TP
.B \-merge \ \ \ 
Use merge mode. It simulates the merge of transitions with adding a special 
merged transition and hiding everything else.
.TP
.B \-sync \ \ \ 
Use synchronous mode. It enables the generation of merged transitions.
The option should be used only on synchronous programs.
.TP
.B \-warning \ \ \ 
No warning is issued.
.TP
.B \-showall \ \ \ 
Show all transitions.
.TP
.B \-onlyroot \ \ \ 
Translate only root system.
.TP
.B \-force \ \ \ 
Overwrite the output files, even if they were edited by the user or do not need 
to be updated.
.TP
.B \-relabel \ \ \ 
Generate a rename file to match formal definition of LTS labels (required by 
other tools).
.TP
.B \-root instantiation \ \ \ 
where \fIinstantiation\fP can take two different forms: \fBsystem\fP, or a 
character string of the form "\fIsystem (X1, ..., Xn)\fP" 
where \fIX1, ..., Xn\fP are values of the constant parameters of the system. It 
is highly recommended to type given parameters using syntax \fIof type\fP.
.br
If the option is specified, only the system \fBsystem\fP will be treated.
\fBgrl2lnt\fP will generate a Main process calling the process of the root 
system in the LNT specification.
By default, if the \fB\-root\fP option is absent, it is assumed that there is 
only one system in the program or that there exists a system called \fBMain\fP.

.SH OPERANDS

.PD 0
.TP 16
.IB filename .grl
GRL specification (input)
.TP
.BI pp_file .grl
GRL code (optional output)
.TP
.BI filename .lnt
LNT code (output)
.TP
.BI filename .fnt
C code (optional output)
.TP
.BI filename .ren
rename file (optional output)

.SH ENVIRONMENT VARIABLES

.TP
.B $GRL_LOCATION
Needed. The path of directory where GRL is installed.

.SH FILES

.PD 0
.TP 18
.B $GRL_LOCATION/lnt/GRL_V1.lnt
GRL predefined library (LNT code)
.TP
.B $GRL_LOCATION/incl/GRL_V1.h 
GRL predefined library (C code)

.SH EXIT STATUS

If the translation was successful the exit status is 0. If any error occurred 
during translation, the exit status is 1 and error messages are issued.

.SH AUTHORS
.P
Eric Leo.

.SH SEE ALSO
.br
.BR grl (LOCAL),
.BR grl.open (LOCAL),
.BR lnt.open (LOCAL),
.BR lnt2lotos (LOCAL),
.BR caesar.adt (LOCAL),
.BR caesar (LOCAL).

.P
Additional information is available from the CADP Web page located at
http://cadp.inria.fr
.P
Directives for installation are given in files \fB$GRL_LOCATION/INSTALLATION\fP.
.P
Recent changes and improvements to this software are reported
and commented in file \fB$GRL_LOCATION/VERSION\fP.

.SH BUGS

Some incorrect GRL programs may be accepted by \fBgrl2lnt\fP and translated 
into LNT. However, errors will be detected by the LNT and LOTOS compilers 
\fBlnt2lotos\fP, \fBcaesar\fP and \fBcaesar.adt\fP.

Please report any bug to cadp@inria.fr

